"use strict";

exports.__esModule = true;
exports.default = void 0;

var _react = _interopRequireWildcard(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _classnames = _interopRequireDefault(require("classnames"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) newObj[key] = obj[key]; } } newObj.default = obj; return newObj; } }

function _typeof(obj) { if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _inheritsLoose(subClass, superClass) { subClass.prototype = Object.create(superClass.prototype); subClass.prototype.constructor = subClass; subClass.__proto__ = superClass; }

var BareHighlight =
/*#__PURE__*/
function (_PureComponent) {
  _inheritsLoose(BareHighlight, _PureComponent);

  function BareHighlight() {
    var _temp, _this;

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    return (_temp = _this = _PureComponent.call.apply(_PureComponent, [this].concat(args)) || this, Object.defineProperty(_this, "state", {
      configurable: true,
      enumerable: true,
      writable: true,
      value: {
        highlightedCode: null,
        language: null
      }
    }), _temp) || _this;
  }

  var _proto = BareHighlight.prototype;

  _proto.componentDidMount = function componentDidMount() {
    this.highlightCode();
  };

  _proto.componentWillReceiveProps = function componentWillReceiveProps(nextProps) {
    // If the text changed make sure to reset the state
    // This way we ensure that the new text is immediately displayed.
    if (nextProps.children !== this.props.children) {
      this.setState({
        highlightedCode: null,
        language: null
      });
    }
  };

  _proto.componentDidUpdate = function componentDidUpdate() {
    // Do not call highlight.js if we already have highlighted code
    // If the children changed highlightedCode will be null
    if (this.state.highlightedCode) return;
    this.highlightCode();
  };

  _proto.getInitialCode = function getInitialCode() {
    var type = _typeof(this.props.children);

    if (type !== 'string') {
      throw new Error("Children of <Highlight> must be a string. '" + type + "' supplied");
    }

    return this.props.children;
  };

  _proto.getHighlightPromise = function getHighlightPromise() {
    var _this2 = this;

    var _props = this.props,
        highlightjs = _props.highlightjs,
        languages = _props.languages;
    return new Promise(function (resolve) {
      if (languages && languages.length === 1) {
        resolve(highlightjs.highlight(languages[0], _this2.getInitialCode()));
      } else {
        resolve(highlightjs.highlightAuto(_this2.getInitialCode(), languages));
      }
    });
  };

  _proto.highlightCode = function highlightCode() {
    var _this3 = this;

    var _props2 = this.props,
        languages = _props2.languages,
        worker = _props2.worker;

    if (worker) {
      worker.onmessage = function (event) {
        return _this3.setState({
          highlightedCode: event.data.value,
          language: event.data.language
        });
      };

      worker.postMessage({
        code: this.getInitialCode(),
        languages: languages
      });
    } else {
      this.getHighlightPromise().then(function (result) {
        return _this3.setState({
          highlightedCode: result.value,
          language: result.language
        });
      });
    }
  };

  _proto.render = function render() {
    var code = this.state.highlightedCode;
    var classes = (0, _classnames.default)(this.props.className, 'hljs', this.state.language);

    if (code) {
      return _react.default.createElement("pre", null, _react.default.createElement("code", {
        className: classes,
        dangerouslySetInnerHTML: {
          __html: code
        }
      }));
    }

    return _react.default.createElement("pre", null, _react.default.createElement("code", {
      className: classes
    }, this.getInitialCode()));
  };

  return BareHighlight;
}(_react.PureComponent);

exports.default = BareHighlight;
Object.defineProperty(BareHighlight, "defaultProps", {
  configurable: true,
  enumerable: true,
  writable: true,
  value: {
    className: '',
    languages: [],
    worker: null
  }
});
process.env.NODE_ENV !== "production" ? BareHighlight.propTypes = {
  children: _propTypes.default.string.isRequired,
  className: _propTypes.default.string,
  highlightjs: _propTypes.default.object.isRequired,
  // eslint-disable-line react/forbid-prop-types
  languages: _propTypes.default.arrayOf(_propTypes.default.string),
  worker: _propTypes.default.object // eslint-disable-line react/forbid-prop-types

} : void 0;